// ==== Standard POV-Ray Includes ====
#include "colors.inc"	// Standard Color definitions
#include "textures.inc"	// Standard Texture definitions
#declare cam_loc = <0.001,20,0>*1.2// Declare camera location for Lens Flare plugin
#declare lookat = <0,0,(-200+(clock*400))> // Declare look_at for Lens Flare  plugin

#include "starfield.inc"
object {StarField}

camera {
    direction <0,0,1.8>
	/*
	#declare Foo = 40
	orthographic
	right <Foo*(4/3),0,0>
	up <0,Foo,0>
	*/
	location cam_loc
	look_at lookat
}

light_source { // Light source near camera for scene development
  cam_loc+<0,5,-40>
  colour rgb 1
}

light_source {
    <20,0,25>
    colour rgb 0.8
}

#include "mftextures.inc"
#include "mfturret.inc"
#include "mfcockpit.inc"
#include "mfdetails.inc"
#include "mfradar.inc"

#declare MFC1 = 9.09
#declare MFC2 = 2.84
#declare MF_SolarSensor = object {
	union {
		object {
			difference {
				object {cone {<0,0,0>, 1.3, <0,0.4,0>, 1.1}}
				object {cylinder {<0,0.2,0>, <0,0.5,0>, 1}}
			}
			texture {MF_HullTexFlatGrey}
		}
		object {
			cylinder {<0,0.2,0>, <0,0.3,0>, 1}
			texture {MF_GrilleTex1}
		}
	}
}
object {
	cylinder {<-10,0,0>, <10,0,0>, 0.1}
	texture {
		pigment {colour White}
		finish {ambient 1}
	}
}
object {
	cylinder {<0,0,-10>, <0,0,10>, 0.1}
	texture {
		pigment {colour White}
		finish {ambient 1}
	}
}

#declare MF_HullDetailP1 = object {
	union {
		object {torus {0.3,0.1} translate <0,0,-5>  rotate <-MFC1,0,0> translate <0,MFC2,0> rotate <0,-35,0>}
		object {cylinder {<-0.5,0,0>, <0.5,0,0>, 0.2} rotate <0,10,0> translate <0,0,-5>   rotate <-MFC1,0,0> translate <0,MFC2,0> rotate <0,-15,0>}
		object {
			union {
				object {cylinder {<0,0,-6.2>, <0,0,-12>, 0.05}}
				object {torus {0.2,0.05} translate <0,0,-6>}
				object {sphere {<0,0,-12>, 0.075}}
			}
			rotate <-MFC1,0,0> translate <0,MFC2,0> rotate <0,-45,0>
		}
		object {
			union {
				object {sphere {<0,0,-9>, 0.15}}
				object {cylinder {<0,0,-9>, <0,0,-15>, 0.05}}
				object {box {<-0.2,0,-12>, <0.3,0.1,-11>}}
				object {cylinder {<0.05,0.1,-11.5>, <0.05,0.2,-11.5>, 0.15}}
			}
			rotate <-MFC1,0,0> translate <0,MFC2,0> rotate <0,-10,0>
		}
	}
}

#declare MF_HullRearTopDetail = object {
	union {
		object {
			intersection {
				object {cone {<0,0,0>, 16.5, <0,2,0>, 4} translate <0,0.2,0>}
				object {plane {<1,0,0>, 0} rotate <0,-(95/2), 0>}
				object {plane {<-1,0,0>, 0} rotate <0,(95/2), 0>}
				object {cylinder {<0,0,0>, <0,5,0>, 4.2} inverse}
				object {box {<-11.5, 0, -20>, <11.5,3,0>}}
			}
			#declare RearHullBumps = normal {
				bump_map {gif "mfhullrearbm.gif" bump_size 2}
			}
			texture {
				material_map {
					gif "mfhullreartm.gif"
					texture {MF_HullTexFlatGrey scale (1/34) normal {RearHullBumps}}
					texture {MF_HullTexRed scale (1/34) normal {RearHullBumps}}
					texture {MF_HullTexDarkGrey scale (1/34) normal {RearHullBumps}}
					texture {MF_HullTexRust scale (1/34) normal {RearHullBumps}}
				}
				rotate <90,0,0>
				translate <-0.5,0,-0.5>
				scale <(18*(4/3)), 1, 18>
				translate <0,0,-9>
			}
		}
		object {
			difference {
				object {torus {16.5,0.2}}
				object {box {<-11.5, -1, -20>, <11.5,3,0>} inverse}
				#declare Count = 0
				#while (Count < 13)
				object {cylinder {<-0.1,0,-16.5>, <0.1,0,-16.5>, 0.4} rotate <0,-45,0> rotate <0,(Count*(90/13)), 0>}
				#declare Count = Count + 1
				#end
			}
			translate <0,0.2,0>
		}
		object {
			union {
				#declare Count = 0
				#while (Count < 13)
				object {
					union {
						object {
							difference {
								object {box {<-0.2,0,-15.4>, <0.2,0.3,-15>}}
								object {box {<-0.1,0.1,-15.5>, <0.1,0.4,-14.9>}}
							}
						}
						object {cone {<0,0,-15.4>, 0.15, <0,0,-16.1>, 0.01}}
						object {box {<-0.1,0,-16.25>, <0.1,0.1,-16>}}
					}
					rotate <-MFC1,0,0> translate <0,MFC2,0>
					rotate <0,-45+((90/13)/2),0> rotate <0,(Count*(90/13)), 0>
				}
				#declare Count = Count + 1
				#end
			}
			texture {MF_HullTexFlatGrey}
		}
		object {
			union {
				#declare Count = 0
				#while (Count < 13)
				object {
					union {
						object {torus {0.2,0.03} rotate <0,0,90> translate <-0.13,0,-16.5>}
						object {torus {0.2,0.03} rotate <0,0,90> translate <0.13,0,-16.5>}
					}
					rotate <0,-45,0> rotate <0,(Count*(90/13)), 0>
				}
				#declare Count = Count + 1
				#end
			}
			translate <0,0.2,0>
			texture {MF_HullTexDarkGrey}
		}
		#declare MF_Gribble = object {
			intersection {
				object {box {<-0.1,0,-1>, <0.1,1,0.25>}}
				object {
					union {
						object {cone {<0,0,-1>, 0, <0,0,-0.1>, 1}}
						object {cylinder {<0,0,-0.1>, <0,0,0>, 1}}
						object {cone {<0,0,1>, 1, <0,0,0.25>, 0}}
					}
				}
			}
			translate <0,0,-15>
			rotate <-MFC1,0,0> translate <0,MFC2,0>
		}
		object {MF_Gribble	rotate <0,-45,0> rotate <0,(1*(90/13)), 0>}
		object {MF_Gribble	rotate <0,-45,0> rotate <0,(5*(90/13)), 0>}
		object {MF_Gribble	rotate <0,-45,0> rotate <0,(8*(90/13)), 0>}
		object {MF_Gribble	rotate <0,-45,0> rotate <0,(12*(90/13)), 0>}
		object {MF_SolarSensor translate <0,0,-7> rotate <-MFC1,0,0> translate <0,MFC2,0> rotate <0,0,0>}
		object {MF_SolarSensor translate <0,0,-10> rotate <-MFC1,0,0> translate <0,MFC2,0> rotate <0,0,0>}
		object {MF_SolarSensor translate <0,0,-7> rotate <-MFC1,0,0> translate <0,MFC2,0> rotate <0,20,0>}
		object {MF_SolarSensor translate <0,0,-10> rotate <-MFC1,0,0> translate <0,MFC2,0> rotate <0,20,0>}
		object {MF_SolarSensor translate <0,0,-7> rotate <-MFC1,0,0> translate <0,MFC2,0> rotate <0,-20,0>}
		object {MF_SolarSensor translate <0,0,-10> rotate <-MFC1,0,0> translate <0,MFC2,0> rotate <0,-20,0>}
		object {MF_HullDetailP1 scale <1,1,1>}
		object {MF_HullDetailP1 scale <-1,1,1>}
	}
	texture {MF_HullTexFlatGrey}
}


#declare MF_EscapePodTubeDetail = object {
	union {
		object {
			box {<5.5,0,-0.9>, <7.5,0.1,0.7>}
			texture {MF_HullTexFlatGrey}
		}
		object {
			cylinder {<6.2,0.1,-0.1>, <6.2,0.2,-0.1>, 0.6}
			texture {MF_HullTexFlatGrey}
		}
		object {
			cylinder {<6,0,0.2>, <10,0,0.2>, 0.1}
			texture {MF_GunMetal1}
		}
		object {
			cylinder {<6,0,-0.3>, <13,0,-0.3>, 0.1}
			texture {MF_GunMetal1}
		}
		object {
			cylinder {<6,0,0.2>, <8,0,0.2>, 0.2}
			texture {MF_GunMetal1}
		}
		object {
			union {
				object {
					difference {
						object {cylinder {<0,0,0>, <0,0.1,0>, 0.3}}
						object {cylinder {<0,-0.1,0>, <0,0.2,0>, 0.2}}
					}
				}
				#declare Count = 0
				#while (Count < 360)
				object {
					box {<-0.025,0,0.21>, <0.025,0.1,0.5>}
					rotate <0,Count,0>
				}
				#declare Count = Count + (360/10)
				#end
			}
			texture {MF_HullTexFlatGrey}
			translate <6.2,0.2,-0.1>
		}

		object {
			intersection {
				object {box {<-0.6,0,-1>, <0.6,0.1,1>} rotate <0,0,0>}
				object {box {<-0.6,0,-1>, <0.6,0.2,1>} rotate <0,60,0>}
				object {box {<-0.6,0,-1>, <0.6,0.2,1>} rotate <0,120,0>}
			}
			translate <10,0.1,0>
			texture {MF_HullTexFlatGrey}
		}
		object {
			box {<9,0,-0.8>, <11,0.1,0.8>}
			texture {MF_HullTexDarkGrey}
		}
		object {
			union {
				object {box {<9,0,-1.1>, <11,0.1,-0.9>}}
				object {cylinder {<0,0.1,0>, <0,0.15,0>, 0.07} translate <9.25,0.1,-1>}
				object {cylinder {<0,0.1,0>, <0,0.15,0>, 0.07} translate <9.75,0.1,-1>}
				object {cylinder {<0,0.1,0>, <0,0.15,0>, 0.07} translate <10.25,0.1,-1>}
				object {cylinder {<0,0.1,0>, <0,0.15,0>, 0.07} translate <10.75,0.1,-1>}
			}
			texture {MF_HullTexFlatGrey}
			scale <0.9,1,1>
		}

		object {
			difference {
				object {cylinder {<0,0,0>, <0,0.1,0>, 0.5}}
				object {cylinder {<0,-0.1,0>, <0,0.2,0>, 0.4}}
			}
			translate <10,0.2,0>
			texture {MF_HullTexFlatGrey}
		}
		object {
			cylinder {<10,0.2,0>, <10,0.25,0>, 0.45}
			texture {MF_GrilleTex1}
		}
		object {
			difference {
				object {cylinder {<0,0,0>, <0,0.1,0>, 0.7}}
				object {cylinder {<0,-0.1,0>, <0,0.2,0>, 0.6}}
			}
			translate <13,0.1,0>
			texture {MF_HullTexFlatGrey}
		}
		object {
			cylinder {<13,0,0>, <13,0.1,0>, 0.8}
			texture {MF_HullTexDarkGrey}
		}
		object {
			cylinder {<13,0.1,0>, <13,0.15,0>, 0.65}
			texture {MF_GrilleTex1}
		}
		object {
			cylinder {<14.5,0,-1>, <14.5,0,1>, 0.1}
			texture {MF_HullTexFlatGrey}
		}
		object {
			cylinder {<14.5,0,-0.7>, <14.5,0,0.7>, 0.2}
			texture {MF_HullTexFlatGrey}
		}
	}
	texture {MF_HullTexDarkGrey}
	translate <-1,0,0>
}

#declare MF_EscapePodTube = object {
	union {
		object {
			intersection {
				object {
					cone {<0,0,0>, 3, <0,2.1,0>, 1.2}
					scale <1000,1,1>
					rotate <0,0,-4>
					translate <0,0.4,0>
				}
				object {box {<4.25,0,-4>, <14.001,4,4>}}
			}
			texture {
				MF_HullTexFlatGrey
				normal {
					bump_map {
						gif "mf_epbm.gif"
					}
					rotate <-90,0,0>
					translate <-0.5,0,-0.5>
					scale <12,1,9>
					translate <9,0,0>
				}
			}

		}
		object {
			MF_EscapePodTubeDetail
			translate <0,2.1,0>
			rotate <0,0,-4>
			translate <0,0.4,0>
		}
	}
	texture {MF_HullTexFlatGrey}
}

#declare MF_HullSidePodIntDetail = object {
	intersection {
		object {
			height_field {gif "mfhf1.gif"}
			translate <-0.5,0,-0.5>
			rotate <0,90,0>
			scale 2
			scale <1.55,0.15,1.55>
		}
		object {
			cylinder {<0,0,0>, <0,0.5,0>, 1.55}
		}
	}
	texture {
		MF_HullTexFlatGrey
	}
}


#declare MF_HullSidePod = object {
	union {
		object {MF_HullSidePodIntDetail rotate <0,0,-90> translate <15,0,0>}
		object {
			difference {
				object {cone {<14,0,0>, 2.15, <15.5,0,0>, 1.75}}
				object {cylinder {<15,0,0>, <16,0,0>, 1.55}}
			}
		}
		object {
			difference {
				object {
					union {
						object {box {<14,-2.5,-0.025>, <14.5,2.5,0.025>} rotate <20,0,0>}
						object {box {<14,-2.5,-0.025>, <14.5,2.5,0.025>} rotate <-20,0,0>}
					}
				}
				object {torus {2.5,0.3} scale <1,1,1> rotate <0,0,90> translate <14.5,0,0>}
			}
		}
		object {
			intersection {
				object {box {<14,-2.4,-3>, <14.05,2.4,3>} rotate <0,0,0>}
				object {box {<14,-2.4,-3>, <14.05,2.4,3>} rotate <50,0,0>}
				object {box {<14,-2.4,-3>, <14.05,2.4,3>} rotate <130,0,0>}
			}
		}
	}
	texture {MF_HullTexFlatGrey}
}

#declare MF_RightHullCentreSideDetail = object {
	union {
		object {cone {<15.2,0,0>, 0.5, <15.8,0,0>, 0.4} rotate <0,-20,0>}
		object {cone {<15.2,0,0>, 0.5, <15.9,0,0>, 0.2} rotate <0,-20,0>}
		object {
			intersection {
				object {cylinder {<0,-1,0>, <0,1,0>, 15.7}}
				object {
					union {
						object {box {<15.5,0.2,-0.5>, <15.8,0.8,0.5>} rotate <0,-13,0>}
						object {box {<15.5,0.6,-0.1>, <15.8,0.8,0.2>} rotate <0,-20,0>}
						object {box {<15.5,0.2,-0.2>, <15.8,0.8,0.2>} rotate <0,-25,0>}
						object {box {<15.5,-0.95,-0.6>, <15.9,-0.65,0.6>} rotate <0,-18,0>}
					}
				}
			}
		}
		object {sphere {<15.6,0,0>, 0.1} rotate <0,-12,0>}
		object {sphere {<15.6,0,0>, 0.1} rotate <0,-30,0>}
		object {
			intersection {
				object {torus {15.6,0.08}}
				object {plane {<0,0,-1>, 0} rotate <0,12,0>}
				object {plane {<0,0,1>, 0} rotate <0,30,0>}
			}
		}
		object {cylinder {<15.5,-0.8,-0.45>, <15.8,-0.8,-0.45>, 0.1} rotate <0,-18,0>}
		object {cylinder {<15.5,-0.8,-0.15>, <15.8,-0.8,-0.15>, 0.1} rotate <0,-18,0>}
		object {cylinder {<15.5,-0.8,0.15>, <15.8,-0.8,0.15>, 0.1} rotate <0,-18,0>}
		object {cylinder {<15.5,-0.8,0.45>, <15.8,-0.8,0.45>, 0.1} rotate <0,-18,0>}
	}
	scale <-1,1,1>
}
#declare MF_LeftHullCentreSideDetail = object {
	union { // Hull centre radius is 15.6, top is 1, bottom is at -1
		object {MF_RightHullCentreSideDetail scale <-1,1,1>} // Mirror image of shared elements
		object { // Junction point between cylindrical hull and mandible
			union {
				object {
					superellipsoid {<1,0.2>}
					scale <0.5,1.2,0.8>
					rotate <0,18,0>
					translate <15.65,0.3,0>
					rotate <0,-38,0>
				}
				object {
					box {<0,-1,-0.3>, <1,0,0.3>}
					scale <0.5,1,1>
					rotate <0,18,0>
					translate <15.65,0,0>
					rotate <0,-38,0>
				}
				object {
					box {<0,-1,-0.6>, <1,-0.9,0.6>}
					scale <0.5,1,1>
					rotate <0,18,0>
					translate <15.65,0,0>
					rotate <0,-38,0>
				}
				object {
					box {<0,-0.2,-0.3>, <1.3,0.2,0.3>}
					scale <0.5,1,1>
					rotate <0,18,0>
					translate <15.65,0,0>
					rotate <0,-38,0>
				}
				object {
					box {<0,0,-0.2>, <1,0.9,0.2>}
					scale <0.5,1,1>
					rotate <0,18,0>
					translate <15.65,0,0>
					rotate <0,-38,0>
				}
				object {
					intersection {
						object {superellipsoid {<0.2,0.2>}}
						object {box {<-0.5,-1.1,-1.1>, <0,1.1,1.1>}}
					}
					scale <1, 1.2, 0.8>
					rotate <0,18,0>
					translate <15.65,0.3,0>
					rotate <0,-38,0>
				}
			}
		}
	}
	texture {MF_HullTexFlatGrey}
	scale <-1,1,1>
}

#declare MF_HullCentre = object {
	union {
		object {
			difference {
				object {cylinder {<0,-1,0>, <0,1,0>, 15.6}}
				object {cylinder {<0,-0.1,0>, <0,3,0>, 3.8}} // Hole below top gun turret
				object {cone {<0,0,-8>, 0.5, <0,0,-11.5>, 1.5} scale <1,10,1> rotate <0,-60,0>}
				object {cone {<0,0,-8>, 0.5, <0,0,-11.5>, 1.5} scale <1,10,1> rotate <0,60,0>}
				object {cone {<14,0,0>, 2.55, <17,0,0>, 3.55} scale <1,10,1>}
				object {cone {<14,0,0>, 2.55, <17,0,0>, 3.55} scale <-1,10,1>}
				object { // Odd-shaped access hatch at front right of top gun turret
					union {
						object {cone {<-0.2,0,10>, 0.5, <-0.2,0,10.5>, 0.9}}
						object {cylinder {<0,0,10.49>, <0,0,11.31>, 0.8}}
						object {cone {<0,0,11.3>, 0.8, <0,0,11.81>, 0.4}}
						object {cylinder {<0,0,11.8>, <0,0,12>, 0.4}}
					}
					scale <1,10,1>
					rotate <0,35,0>
				}
				object { // Cutaway between mandibles
					box {<-3,-2,10>, <3,2,16>}
				}
				object { // Cutaway for engine glow at rear
					intersection {
						object {plane {<1,0,0>, 0} rotate <0,-(95/2), 0>}
						object {plane {<-1,0,0>, 0} rotate <0,(95/2), 0>}
					}
				}

			}
		}
		object {MF_LeftHullCentreSideDetail}
		object {MF_RightHullCentreSideDetail}
		object { // Observation window behind missile launcher
			difference {
				object {box {<-3,-1,14.5>, <3,1,15>}}
				object {box {<-2.2,0,14>, <2.2,0.7,16>}}
			}
			texture {MF_HullTexFlatGrey}
		}
		object {
			box {<-2.5,0,14.6>, <2.5,0.8,14.9>}
			texture {pigment {colour rgb 0}}
		}
	}
	texture {MF_HullTexFlatGrey}
}



#declare MF_HullShape = object {
	union {
		object {
			difference { // Main 'shape' before detailing added
				object {
					union {
						object {cylinder {<0,0,0>, <0,0.1,0>, 16}}
						object {cone {<0,0.1,0>, 16, <0,1.8,0>, 4}}
					}
				}
				object {cone {<0,0.1,0>, 16, <0,1.8,0>, 4} translate <0,-0.2,0>}
				object {cylinder {<0,-0.1,0>, <0,3,0>, 3.8}} // Hole below top gun turret
				object {cylinder {<0,-1,0>, <0,2,0>, 1.4} translate <0,1,11.5> rotate <0,-35,0> texture {pigment {colour rgb 0}}}
				object {cone {<0,0,-8>, 0.5, <0,0,-11.5>, 1.5} scale <1,10,1> rotate <0,-60,0>}
				object {cone {<0,0,-8>, 0.5, <0,0,-11.5>, 1.5} scale <1,10,1> rotate <0,60,0>}
				object {cone {<14,0,0>, 2.5, <17,0,0>, 3.5} scale <1,10,1>}
				object {cone {<14,0,0>, 2.5, <17,0,0>, 3.5} scale <-1,10,1>}
				object { // Odd-shaped access hatch at front right of top gun turret
					union {
						object {cone {<-0.2,0,10>, 0.5, <-0.2,0,10.5>, 0.9}}
						object {cylinder {<0,0,10.49>, <0,0,11.31>, 0.8}}
						object {cone {<0,0,11.3>, 0.8, <0,0,11.81>, 0.4}}
						object {cylinder {<0,0,11.8>, <0,0,12>, 0.4}}
					}
					scale <1,10,1>
					rotate <0,35,0>
				}
			}

			#declare HullBumps = normal {
				bump_map {gif "hulltpbm.gif" bump_size 1.5}
			}
			texture {
				material_map {
					gif "hulltpim.gif"
					texture {MF_HullTexFlatGrey scale (1/34) normal {HullBumps}}
					texture {MF_HullTexRed scale (1/34) normal {HullBumps}}
					texture {MF_HullTexDarkGrey scale (1/34) normal {HullBumps}}
					texture {MF_HullTexRust scale (1/34) normal {HullBumps}}
				}
				rotate <90,0,0>
				translate <-0.5,0,-0.5>
				scale 34
			}
		}
		object {MF_TopLaserTurret translate <0,1.8,0>}
		object {MF_HullRearTopDetail}
		object {MF_EscapePodTube scale <1,1,1>}
		object {MF_EscapePodTube scale <-1,1,1>}
	}
	texture {MF_HullTexFlatGrey}
}

#declare MF_HullTop = object {
    union {
        object {MF_HullShape}
   		object {MF_RadarDish translate <0,1,11.5> rotate <0,-35,0>}
    }
}

#declare MF_HullBottom = object {MF_HullShape scale <1,-1,1>}

#declare MF_EngineGlow = object {
	intersection {
		object {plane {<1,0,0>, 0} rotate <0,-(95/2), 0>}
		object {plane {<-1,0,0>, 0} rotate <0,(95/2), 0>}
		object {cylinder {<0,-1,0>, <0,1,0>, 15.5}}
	}
	texture {
		pigment {colour rgb <0.9,0.9,1>}
		finish {ambient 1 diffuse 0}
	}
}

#declare MF_MandibleCentre = object {
	intersection {
		object {box {<-15.1,-0.9,0>, <0,0.9,40>} rotate <0,22,0>}
		object {box {<-20,-2,0>, <-2.5,2,30>}}
		object {cylinder {<-7.5,-3,16>, <-7.5,3,16>, 1.6} inverse}
		object {cylinder {<-5,-3,22>, <-5,3,22>, 1.6} inverse}
	}
}
#declare MF_MandibleTop = object {
	union {
		object {
			intersection {
				object {box {<-15.5,0.9,0>, <0,1,40>} rotate <0,22,0>}
				object {box {<-20,-2,0>, <-2.4,2,30>}}
				object {cylinder {<-7.5,0,16>, <-7,2,16>, 1.2} inverse}
				object {cylinder {<-5,0,22>, <-5,2,22>, 1.2} inverse}
			}
			texture {
				MF_HullTexFlatGrey
				normal {
					bump_map {gif "platemap2.gif" bump_size 1}
					rotate <90,0,0>
					scale 12
				}
			}
		}
		object {box {<-2.6, 1, 24>, <-2.5, 1.6, 30>}}
		object {
			intersection {
				object {box {<-2.6,1,23>, <-2.5,1.6,30>}}
				object {cone {<0,1,0>, 1, <0,1.6,0>, 0} scale <10,1,1> translate <-2.6,0,24>}
			}
		}
		object {box {<-3.5, 1, 29.1>, <-2.6,1.4,29.9>}}
		object {box {<-3.5, 1, 29.6>, <-2.6,1.6,29.9>}}
		object {cylinder {<-3,1.4,29.1>, <-3,1.4,29.8>, 0.05}}
		object {cylinder {<-3.2,1.4,29.1>, <-3.2,1.4,29.8>, 0.05}}
		object {cylinder {<-3,1,10>, <-3,1,30>, 0.05}}
		object {cylinder {<-2.7,1,10>, <-2.7,1,30>, 0.05}}
	}
}

#declare MF_LeftMandibleSideDetail = object {
	height_field {gif "mflmhf.gif"}
	translate <-0.5,0,-0.5>
	rotate <0,90,0>
	scale <1.8,0.4,20>
	rotate <0,0,90>
	translate <0,0,15.5>
	translate <-15.101,0,0>
	rotate <0,22,0>
}

#declare MF_RightMandibleSideDetail = object {
	height_field {gif "mfrmhf.gif"}
	translate <-0.5,0,-0.5>
	rotate <0,90,0>
	scale <1.8,0.4,20>
	rotate <0,0,90>
	translate <0,0,15.5>
	translate <-15.101,0,0>
	rotate <0,22,0>
	scale <-1,1,1>
}

#declare MF_MandibleBottom = object {
	union {
		object {
			intersection {
				object {box {<-15.5,0.9,0>, <0,1,40>} rotate <0,22,0>}
				object {box {<-20,-2,0>, <-2.4,2,30>}}
				object {cylinder {<-7.5,0,16>, <-7,2,16>, 1.2} inverse}
				object {cylinder {<-5,0,22>, <-5,2,22>, 1.2} inverse}
			}
			texture {
				MF_HullTexFlatGrey
				normal {
					bump_map {gif "platemap2.gif" bump_size 1}
					rotate <90,0,0>
					scale 12
				}
			}
		}
		object {box {<-2.5, 1, 24>, <-2.4, 1.6, 30>}}
		object {
			intersection {
				object {box {<-2.5,1,23>, <-2.4,1.6,30>}}
				object {cone {<0,1,0>, 1, <0,1.6,0>, 0} scale <10,1,1> translate <-2.5,0,24>}
			}
		}
	}
	scale <1,-1,1>
}

#declare MF_RightMandible = object {
	union {
		object {MF_RightMandibleSideDetail}
		object {MF_MandibleCentre scale <-1,1,1>}
		object {MF_MandibleTop scale <-1,1,1>}
		object {MF_MandibleBottom scale <-1,1,1>}
		object {MF_InternalDetailMFTL translate <5,0,22>}
		object {MF_InternalDetailMFBL translate <5,0,22> scale <1,-1,1>}
		object {MF_InternalDetailMRTL translate <7.5,0,16>}
		object {MF_InternalDetailMRBL translate <7.5,0,16> scale <1,-1,1>}
		object {
			union {
				object {cylinder {<0,0,0>, <0,0,-20>, 0.05}}
				object {sphere {<0,0,0>, 0.06}}
				object {sphere {<0,0,-20>, 0.06}}
			}
			rotate <0,-22,0>
			translate <4.5,1,29>
			texture {MF_HullTexFlatGrey}
		}
		object {
			union {
				object {cylinder {<0,0,0>, <0,0,-5>, 0.05}}
				object {sphere {<0,0,0>, 0.06}}
				object {sphere {<0,0,-5>, 0.06}}
				object {cylinder {<0,0,0>, <0,-1,0>, 0.05}}
				object {cylinder {<0,0,-5>, <0,-1,-5>, 0.05}}
			}
			rotate <0,-22,0>
			translate <5,1,21>
			texture {MF_ChromeMetal}
		}
		object {
			union {
				object {cylinder {<0,0,0>, <0,0,2>, 0.05}}
				object {cylinder {<0,-1,0>, <0,0,0>, 0.05}}
				object {cylinder {<0,0,0>, <0,0,2>, 0.05} rotate <0,32,0> translate <0,0,2>}
				object {sphere {<0,0,0>, 0.075}}
				object {sphere {<0,0,2>, 0.075} rotate <0,32,0> translate <0,0,2>}
				object {sphere {<0,0,2>, 0.075}}
			}
			texture {MF_GunMetal1}
			rotate <0,-32,0>
			translate <5,1,23>
		}


		object { // Assorted other detail on mandibles
			union {
				object {box {<-0.3,0.8,1.1>, <0.2,0.9,1.35>}}
				object {
					intersection {
						object {
							union {
								object {cone {<0,0,1.4>, 0.3, <0,0.8,1.4>, 0.01}}
								object {cylinder {<0,0,0.9>, <0,0.8,0.9>, 0.5}}
								object {cone {<0,0,0.4>, 1, <0,0.8,0.4>, 0.01}}
								object {cylinder {<0,0,0>, <0,0.3,0>, 0.5}}
								object {cylinder {<0,0,-1>, <0,0.5,-1>, 0.5}}
								object {cone {<0,0,-1.5>, 1, <0,0.5,-1.5>, 0.001}}
							}
							scale <100,1,1>
						}
						object {cone {<0,0,0>, 0.4, <0,1,0>, 0.2} scale <1,1,100>}
					}
				}
			}
			scale <1,0.8,1>
			translate <5.5,1,16>
		}
	}
	texture {MF_HullTexFlatGrey}
}

#declare MF_LeftMandible = object {
	union {
		object {MF_LeftMandibleSideDetail}
		object {MF_MandibleCentre}
		object {MF_MandibleTop}
		object {MF_MandibleBottom}
		object {MF_InternalDetailMFTR translate <-5,0,22>}
		object {MF_InternalDetailMFBR translate <-5,0,22> scale <1,-1,1>}
		object {MF_InternalDetailMRTR translate <-7.5,0,16>}
		object {MF_InternalDetailMRBR translate <-7.5,0,16> scale <1,-1,1>}
		object {
			union {
				object {cylinder {<0,0,0>, <0,0,-20>, 0.05}}
				object {sphere {<0,0,0>, 0.06}}
				object {sphere {<0,0,-20>, 0.06}}
			}
			rotate <0,-22,0>
			translate <4.5,1,29>
			texture {MF_HullTexFlatGrey}
			scale <-1,1,1>
		}
		object {
			union {
				object {cylinder {<0,0,0>, <0,0,-5>, 0.05}}
				object {sphere {<0,0,0>, 0.06}}
				object {sphere {<0,0,-5>, 0.06}}
				object {cylinder {<0,0,0>, <0,-1,0>, 0.05}}
				object {cylinder {<0,0,-5>, <0,-1,-5>, 0.05}}
			}
			rotate <0,-22,0>
			translate <5,1,21>
			texture {MF_ChromeMetal}
			scale <-1,1,1>
		}
		object {
			union {
				object {cylinder {<0,0,0>, <0,0,2>, 0.05}}
				object {cylinder {<0,-1,0>, <0,0,0>, 0.05}}
				object {cylinder {<0,0,0>, <0,0,2>, 0.05} rotate <0,32,0> translate <0,0,2>}
				object {sphere {<0,0,0>, 0.075}}
				object {sphere {<0,0,2>, 0.075} rotate <0,32,0> translate <0,0,2>}
				object {sphere {<0,0,2>, 0.075}}
			}
			texture {MF_GunMetal1}
			rotate <0,-32,0>
			translate <5,1,23>
			scale <-1,1,1>
		}


		object { // Assorted other detail on mandibles
			union {
				object {box {<-0.3,0.8,1.1>, <0.2,0.9,1.35>}}
				object {
					intersection {
						object {
							union {
								object {cone {<0,0,1.4>, 0.3, <0,0.8,1.4>, 0.01}}
								object {cylinder {<0,0,0.9>, <0,0.8,0.9>, 0.5}}
								object {cone {<0,0,0.4>, 1, <0,0.8,0.4>, 0.01}}
								object {cylinder {<0,0,0>, <0,0.3,0>, 0.5}}
								object {cylinder {<0,0,-1>, <0,0.5,-1>, 0.5}}
								object {cone {<0,0,-1.5>, 1, <0,0.5,-1.5>, 0.001}}
							}
							scale <100,1,1>
						}
						object {cone {<0,0,0>, 0.4, <0,1,0>, 0.2} scale <1,1,100>}
					}
				}
			}
			scale <1,0.8,1>
			translate <5.5,1,16>
			scale <-1,1,1>
		}
	}
	texture {MF_HullTexFlatGrey}
}

#declare MF_HullFrontTopBitShape = object {
	intersection {
		object {plane {<0,-1,0>, 0} translate <0,0.9,0>}
		object {plane {<0,1,0>, 0} rotate <6, 0, 0> translate <0,3.7,0>}
		object {plane {<0,0,1>, 0} rotate <-25,0,0> translate <0,0,21>}
		object {
			union {
				object {cone {<0,0,4.5>, 3, <0,0,21>, 2.1}}
				object {cone {<0,0,4.5>, 3, <0,0,10>, 3.1}}
			}
			scale <1,100,1>
		}
	}
	texture {
		MF_HullTexFlatGrey
		normal {
			bump_map {gif "platemap3.gif" bump_size 1}
			rotate <90,0,0>
			scale 12
		}
	}
}
#declare MF_HullFrontTopBitDetail = object {
	union {
		object {cylinder {<-2.3,0,0>, <-1.8,0,15>, 0.05}}
		object {cylinder {<2.3,0,0>, <1.8,0,15>, 0.05}}
		object {
			box {<-1.5,0,0>, <1.5,0.05,15>}
			texture {
				MF_HullTexFlatGrey
				normal {
					bump_map {gif "platemap3.gif" bump_size 1}
					rotate <90,0,0>
					scale 12
				}
			}
		}
		object {cylinder {<-1.3,0.05,1.5>, <-0.8,0.05,1.5>, 0.15}}
		object {cylinder {<-0.8,0.05,1.5>, <0.5,0.05,1.5>, 0.05}}
		object {
			union {
				object {
					intersection {
						object {cone {<0,0,0>, 0.2, <0,0,0.5>, 0.05} scale <1,10,1>}
						object {box {<-0.2,0,0>, <0.2,0.2,0.5>}}
					}
				}
				object {cylinder {<0,0,0.5>, <0,0,9.75>, 0.05}}
				object {
					intersection {
						object {torus {0.25,0.05}}
						object {box {<0,-1,0>, <1,1,1>}}
					}
					translate <-0.25,0,9.75>
				}
				object {cylinder {<0,0,10>, <-1,0,10>, 0.05}}
			}
			translate <0.5,0.05,2>
		}
		object {
			union {
				object {
					intersection {
						object {cone {<0,0,0>, 0.2, <0,0,0.5>, 0.05} scale <1,10,1>}
						object {box {<-0.2,0,0>, <0.2,0.2,0.5>}}
					}
				}
				object {cylinder {<0,0,0.5>, <0,0,10.25>, 0.05}}
				object {
					intersection {
						object {torus {0.25,0.05}}
						object {box {<0,-1,0>, <1,1,1>}}
					}
					translate <-0.25,0,10>
				}
				object {cylinder {<0,0,10.25>, <-1.5,0,10.25>, 0.05}}
			}
			translate <1,0.05,2>
		}
		#declare MF_Fnord = object {
			union {
				object {box {<-0.1,0,-0.1>, <0.1,0.1,0.1>}}
				object {cylinder {<0,0,0>, <0,0,0.5>, 0.05}}
				object {
					intersection {
						object {torus {0.25,0.05}}
						object {box {<0,-1,0>, <1,1,1>}}
					}
					translate <-0.25,0,0.5>
				}
				object {cylinder {<-0.25,0,0.75>, <-0.75,0,0.75>, 0.05}}
				object {
					intersection {
						object {torus {0.25,0.05}}
						object {box {<-1,-1,-1>, <0,1,0>}}
					}
					translate <-0.75,0,1>
				}
				object {cylinder {<-1,0,1>, <-1,0,5>, 0.05}}
			}
		}
		object {MF_Fnord translate <-0.1,0.05,3.2>}
		object {MF_Fnord translate <0,0.05,5.4>}
		object {MF_Fnord translate <0.1,0.05,7.6>}
		object {MF_Fnord translate <0.2,0.05,9.8>}
		object {torus {0.3,0.05} translate <0,0.05,13>}
		object {cylinder {<-0.6,0.05,12>, <-0.6,0.15,12>, 0.03}}
		object {cylinder {<-0.6,0.05,12.8>, <-0.6,0.15,12.8>, 0.03}}
		object {cylinder {<-0.6,0.05,13.4>, <-0.6,0.15,13.4>, 0.03}}
		object {cylinder {<0.6,0.05,12>, <0.6,0.15,12>, 0.03}}
		object {cylinder {<0.6,0.05,12.8>, <0.6,0.15,12.8>, 0.03}}
		object {cylinder {<0.6,0.05,13.4>, <0.6,0.15,13.4>, 0.03}}
		object {box {<1.5,0.05,15>, <1.8,0.2,15.3>}}
	}
	texture {MF_HullTexFlatGrey}
}

#declare MF_FrontMissileLaunchers = object {
	union {
		object {
			difference {
				object {cylinder {<0,0,0>, <0,0,4>, 0.3}}
				object {cylinder {<0,0,-1>, <0,0,5>, 0.25} texture {pigment {colour rgb 0}}}
				object {cone {<0,-0.31,4>, 1, <0,0.31,4>, 0} scale <100,1,1>}
			}
			texture {MF_GunMetal1}
		}
		object {box {<-0.8,-0.1,1>, <-0.3,0.1,3>}}
		object {box {<0.3,-0.1,1>, <0.8,0.1,3>}}
		object {box {<-0.6,0.1,1>, <-0.5,0.4,4>}}
		object {box {<0.5,0.1,1>, <0.6,0.4,4>}}
		object {box {<-0.1,0.2,1>, <0.1,0.4,3.5>}}
	}
	translate <0,0.5,15>
	texture {MF_HullTexFlatGrey}
}

#declare MF_HullFrontTopBit = object {
	union {
		object {MF_HullFrontTopBitDetail translate <0,0,5> rotate <6,0,0> translate <0,3.7,0>}
		object {MF_HullFrontTopBitShape}
		object {MF_FrontMissileLaunchers}
	}
}

#declare MF_HullFrontBottomBitDetail = object {
	union {
		object {box {<-0.5,0,1>, <0.5,0.3,4>}}
		object {cylinder {<-1,0,2>, <-1,0,3.5>, 0.2}}
		object {cylinder {<1,0,2>, <1,0,3.5>, 0.2}}
	}
	texture {MF_HullTexFlatGrey}
	translate <0,-0.9,15>
}

#declare MF_HullFrontBottomBit = object {
	union {
		object {MF_HullFrontTopBitDetail translate <0,0,5> rotate <6,0,0> translate <0,3.7,0> scale <1,-1,1>}
		object {MF_HullFrontTopBitShape scale <1,-1,1>}
		object {MF_HullFrontBottomBitDetail}
	}
}

#declare Falcon = object {
	union {
		object {MF_Cockpit}
		object {MF_HullTop translate <0,1,0>}
		object {MF_HullCentre}
		object {MF_HullBottom translate <0,-1,0>}
		object {MF_HullSidePod scale <1,1,1>}
		object {MF_HullSidePod scale <-1,1,1>}
		object {MF_HullFrontTopBit}
		object {MF_HullFrontBottomBit}
		object {MF_RightMandible}
		object {MF_LeftMandible}
		object {MF_EngineGlow}
	}
}
#if (clock>0.5) 
object {Falcon rotate <0,0,360*(clock*2)> translate <0,0,(-200+(clock*400))>}
#else
object {Falcon translate <0,0,(-200+(clock*400))>}
#end


